label {
    width:160px;
    float:left;
}

.modules-sortable{list-style-type:none;cursor:move}

.span-container {
    width: 528px;
    min-height: 0px;
    max-height: none;
    height: 637px;
    position: relative;
}
.mfcr2-settings, .isdn-settings {
    width: 100%;
    height: 100%;
    position: absolute;
    top: 0;
    left: 0;
    padding: 15px 10px 0px 25px;
}
.mfcr2-settings {
    z-index: 10;
}

.mfcr2-label {
    width:265px;
}